@@ -1,3 +1,5 @@
+import logging
+
 from cms.models import Page
 from cms.models.pluginmodel import CMSPlugin
 from django.db import models
@@ -11,6 +13,7 @@ class Type(Enum):
     # TWITTER = 'twitter'
     LINKEDIN = 'linkedin'
     EMAIL = 'email'
+    GITHUB = 'github'
 
 
 class Alignment(Enum):
@@ -34,6 +37,8 @@ class SocialItemAbstract(models.Model):
             return 'fab fa-linkedin-in'
         elif self.type == Type.EMAIL:
             return 'fas fa-envelope'
+        elif self.type == Type.GITHUB:
+            return 'fab fa-github'
         else:
             raise ValueError()
 
@@ -65,7 +70,7 @@ class SocialShareButton(SocialItemAbstract):
                 f'body=Check out this site {meta.url}.'
             )
         else:
-            raise ValueError()
+            logging.error(f"url for type {self.type.value} not found")
 
 
 class SocialLink(SocialItemAbstract):
